@@ -8,7 +8,7 @@ var lo__cpp_8h =
     [ "lo::Blob", "classlo_1_1Blob.html", null ],
     [ "lo::PathMsg", "structlo_1_1PathMsg.html", null ],
     [ "lo::Bundle", "classlo_1_1Bundle.html", null ],
-    [ "immediate", "lo__cpp_8h.html#a08d0e664712018792e5622659e90b2c6", null ],
-    [ "now", "lo__cpp_8h.html#a645b0712d1326a429637a47b491d93c1", null ],
-    [ "version", "lo__cpp_8h.html#a86f98eaf3c32806e08bf8a6084378505", null ]
+    [ "lo::immediate", "lo__cpp_8h.html#a08d0e664712018792e5622659e90b2c6", null ],
+    [ "lo::now", "lo__cpp_8h.html#a645b0712d1326a429637a47b491d93c1", null ],
+    [ "lo::version", "lo__cpp_8h.html#a86f98eaf3c32806e08bf8a6084378505", null ]
 ];
\ No newline at end of file
